@@ -6,7 +6,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -23,6 +23,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 #include <stdio.h>
 
@@ -89,18 +90,18 @@ static XtResource resources[] = {
  *
  ***************************************************************************/
 
-static void ClassInitialize();
-static void Resize();
-static void Redisplay();
-static void Initialize();
-static void InsertChild();
-static void ChangeManaged();
-static XtGeometryResult GeometryManager();
-static XtGeometryResult QueryGeometry();
-static XtGeometryResult LayoutFrame();
-static void Destroy();
-static void GetDesiredSizeOfChild();
-static void GetNaturalSize();
+static void ClassInitialize(void);
+static void Resize(Widget);
+static void Redisplay(Widget,XEvent *,Region);
+static void Initialize(Widget,Widget,ArgList,Cardinal*);
+static void InsertChild(Widget);
+static void ChangeManaged(Widget);
+static XtGeometryResult GeometryManager(Widget,XtWidgetGeometry*,XtWidgetGeometry*);
+static XtGeometryResult QueryGeometry(Widget,XtWidgetGeometry*,XtWidgetGeometry*);
+static XtGeometryResult LayoutFrame(FrameWidget);
+static void Destroy(Widget);
+static void GetDesiredSizeOfChild(Widget);
+static void GetNaturalSize(FrameWidget,Dimension*,Dimension*);
 
 #define SuperClass ((CompositeWidgetClass)&compositeClassRec)
 
@@ -204,7 +205,7 @@ FrameConvertStringToFrameType ( display, args, num_args,  from, to, converter_da
 /*---------------------------------------------------*/
 
 static void
-ClassInitialize()
+ClassInitialize(void)
 {
    BEGINMESSAGE(ClassInitialize)
    XawInitializeWidgetSet();
