@@ -43,9 +43,7 @@
 #include <ctype.h>
 #include <signal.h>
 
-#ifdef HAVE_INTTYPES_H
-  #include <inttypes.h>
-#endif
+#include <inttypes.h>
 
 #ifndef BUFSIZ
 #   define BUFSIZ 1024
@@ -837,7 +835,6 @@ cb_save(w, client_data, call_data)
     pathlen = strlen(path)+strlen(name)+strlen(ext);
     if (pathlen<GV_MAX_FILENAME_LENGTH-1) {
        sprintf(default_path,"%s%s",path,name);
-       file_stripVersionNumber(default_path);
        strcat(default_path,ext);
        XawFileSelectionSetPath(FileSel,default_path);
     }
@@ -1513,6 +1510,7 @@ cb_shutdown(w, client_data, call_data)
    XtDestroyApplicationContext(app_con);
    ENDMESSAGE(cb_shutdown)
    ENDMESSAGE(exiting gv)
+   clean_safe_tempdir();
    exit(EXIT_STATUS_NORMAL);
 }
 
