@@ -49,7 +49,7 @@ extern void			cb_newtocScrollbar (
 #endif
 );
 
-extern void			cb_newtocClipAdjust (
+extern void			cb_newtocVisibleAdjust (
 #if NeedFunctionPrototypes
    Widget,
    XtPointer,
@@ -217,6 +217,14 @@ extern void			cb_savepos (
 #endif
 );
 
+extern void			cb_presentation (
+#if NeedFunctionPrototypes
+   Widget,
+   XtPointer,
+   XtPointer
+#endif
+);
+
 extern void			cb_redisplay (
 #if NeedFunctionPrototypes
    Widget,
