@@ -7,7 +7,7 @@
 ** 
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
+** the Free Software Foundation; either version 3 of the License, or
 ** (at your option) any later version.
 ** 
 ** This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 **           GNU Project
 **
 */
+#include "ac_config.h"
 
 /*
 #define MESSAGES
@@ -196,13 +197,16 @@ static String
 save_forkPDFToPSConversion(sd)
    SaveData sd;
 {
-   char command[512];
+   char command[512], tmp[512];
    char proc_name[256];
    char *error=NULL;
    char *pos;
    char *pdfpos;
    char *pspos;
    char *quoted_src_fn, *quoted_conv_fn;
+   char* src = gv_gs_cmd_scan_pdf;
+   char* dest = tmp;
+   int spaceFound = 0;
 
    BEGINMESSAGE(save_forkPDFToPSConversion)
 
@@ -233,9 +237,27 @@ save_forkPDFToPSConversion(sd)
    }
    GV_XtFree(quoted_src_fn);
    GV_XtFree(quoted_conv_fn);
+   
+   if (strstr(gv_gs_cmd_scan_pdf, "-P") || !gv_gs_safer)
+      strcpy(tmp, gv_gs_cmd_scan_pdf);
+   else
+   {
+      while (*src)
+      {
+         int isSpace = *src == ' ';
+         *(dest++) = *(src++);
+	 if (!spaceFound && isSpace)
+	 {
+	    strcpy(dest, "-P- -dSAFER ");
+	    dest+=12;
+	    spaceFound = 1;
+	 }
+      }
+      *dest = 0;
+   }
 
-   INFSMESSAGE(starting conversion:,command)
-   process_fork(proc_name,command,save_forkPDFToPSConversionDone,(XtPointer)sd);
+   INFSMESSAGE(starting conversion:,tmp)
+   process_fork(proc_name,tmp,save_forkPDFToPSConversionDone,(XtPointer)sd);
    ENDMESSAGE(save_forkPDFToPSConversion)
    return(error);
 }
@@ -269,7 +291,7 @@ save_copyToFile(save_filename,src_filename,pagelist,scanstyle)
 	 String s = GV_XtNewString(src_filename);
 	 s = file_getUsefulName(s);
          INFMESSAGE(scanning document)
-         doc_scanFile(&src_file,&src_doc,src_filename,s,NULL,NULL,NULL,NULL,scanstyle);
+         doc_scanFile(&src_file,&src_doc,src_filename,s,NULL,NULL,NULL,NULL,scanstyle,gv_gs_safeDir);
          if (src_doc) {
             INFMESSAGE(calling pscopydoc)
             pscopydoc(save_file,src_filename,src_doc,pagelist);
@@ -321,8 +343,10 @@ save_saveFile(sd)
      s = GV_XtNewString(s);
      s = file_getUsefulName(s);
      s = file_pdfname2psname(s);
-     sd->conv_fn = file_getTmpFilename(NULL,s);
+     sd->conv_fn = file_getTmpFilename(NULL, s, NULL);
      GV_XtFree(s);
+     if (sd->conv_fn == NULL)
+	     return XtNewString("Cannot create temporary file!");
      INFSMESSAGE(converting from file,sd->src_fn)
      INFSMESSAGE(converting to file,sd->conv_fn)
      error = save_forkPDFToPSConversion(sd);
@@ -337,14 +361,18 @@ save_saveFile(sd)
       if (!sd->save_fn) {
 	s = GV_XtNewString(sd->src_fn);
 	s = file_getUsefulName(s);
-	s = file_pdfname2psname(s);      
-	sd->save_fn = file_getTmpFilename(NULL,s);
+	s = file_pdfname2psname(s);
+	sd->save_fn = file_getTmpFilename(NULL, s, NULL);
 	GV_XtFree(s);
       }
-      INFSMESSAGE(saving from file,src_fn)
-      INFSMESSAGE(saving to file,sd->save_fn)
-      error = save_copyToFile(sd->save_fn,src_fn,sd->pagelist,sd->scanstyle);
-      src_fn = sd->save_fn;
+      if (!sd->save_fn) {
+        error = XtNewString("Cannot create temporary file!");
+      } else {
+        INFSMESSAGE(saving from file,src_fn)
+        INFSMESSAGE(saving to file,sd->save_fn)
+        error = save_copyToFile(sd->save_fn,src_fn,sd->pagelist,sd->scanstyle);
+        src_fn = sd->save_fn;
+      }
    }
 
    if (!error && sd->save_to_printer) {
